@@ -1,15 +1,13 @@
 name = "pydatasci"
 
-import os
+import os, sqlite3
 from os import path
 
-import appdirs, sqlite3
+import appdirs
 
 
-app_name = "pydatasci"
-
-def directoree(app_name):
-	app_dir = user_data_dir(app_name)
+def directoree():
+	app_dir = appdirs.user_data_dir(name)
 	print(app_dir)
 
 def say():
